
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5QuickTest_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5QuickTest_VERSION instead.
set(StaticQt5QuickTest_VERSION_STRING 5.7.1)
set(StaticQt5QuickTest_LIBRARIES StaticQt5::QuickTest)

macro(_qt5_QuickTest_check_file_exists_static FILE)
    if(NOT EXISTS "${FILE}")
        message(FATAL_ERROR "The imported target \"StaticQt5::QuickTest\" references the file
   \"${FILE}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

# ensure also regular/dynamic macro exists because it might be used in some extra config
if(NOT COMMAND _qt5_QuickTest_check_file_exists)
    macro(_qt5_QuickTest_check_file_exists FILE)
        _qt5_QuickTest_check_file_exists_static(${FILE})
    endmacro()
endif()

macro(_populate_QuickTest_target_properties_static TARGET_NAME TARGET_CONFIG LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET ${TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${TARGET_CONFIG})


    set(imported_location "${_qt5QuickTest_install_prefix}/lib/${LIB_LOCATION}")


    _qt5_QuickTest_check_file_exists_static(${imported_location})

    if (_Qt5QuickTest_LIB_DEPENDENCIES)
        set(_list_sep ";")
    endif()
    set_target_properties(${TARGET_NAME} PROPERTIES
        "INTERFACE_LINK_LIBRARIES_${TARGET_CONFIG}" "${_Qt5QuickTest_LIB_DEPENDENCIES}${_list_sep}${_Qt5QuickTest_STATIC_${TARGET_CONFIG}_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${TARGET_CONFIG}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${TARGET_CONFIG}" "${_Qt5QuickTest_LIB_DEPENDENCIES}${_list_sep}${_Qt5QuickTest_STATIC_${TARGET_CONFIG}_LIB_DEPENDENCIES}"
    )

    set(imported_implib "${_qt5QuickTest_install_prefix}/lib/${IMPLIB_LOCATION}")
    _qt5_QuickTest_check_file_exists_static(${imported_implib})
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(StaticQt5::QuickTest PROPERTIES
        "IMPORTED_IMPLIB_${TARGET_CONFIG}" ${imported_implib}
        )
    endif()
endmacro()

set(TARGET_NAME StaticQt5::QuickTest)

if(NOT TARGET ${TARGET_NAME})
    set(_Qt5QuickTest_OWN_INCLUDE_DIRS "${_qt5QuickTest_install_prefix}/include/qt/" "${_qt5QuickTest_install_prefix}/include/qt/QtQuickTest")
    set(StaticQt5QuickTest_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5QuickTest_OWN_INCLUDE_DIRS})
        _qt5_QuickTest_check_file_exists_static(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5QuickTest_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5QuickTest_PRIVATE_INCLUDE_DIRS})
            _qt5_QuickTest_check_file_exists_static(${_dir})
        endforeach()
    endif()

    set(StaticQt5QuickTest_INCLUDE_DIRS ${_Qt5QuickTest_OWN_INCLUDE_DIRS})

    set(StaticQt5QuickTest_DEFINITIONS -DQT_QMLTEST_LIB)
    set(StaticQt5QuickTest_COMPILE_DEFINITIONS QT_QMLTEST_LIB)
    set(_Qt5QuickTest_MODULE_DEPENDENCIES "Test;Widgets;Core")


    set(_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED)
    if (StaticQt5QuickTest_FIND_REQUIRED)
        set(_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5QuickTest_FIND_DEPENDENCIES_QUIET)
    if (Qt5QuickTest_FIND_QUIETLY)
        set(_Qt5QuickTest_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5QuickTest_FIND_VERSION_EXACT)
    if (StaticQt5QuickTest_FIND_VERSION_EXACT)
        set(_Qt5QuickTest_FIND_VERSION_EXACT EXACT)
    endif()

    set(StaticQt5QuickTest_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5QuickTest_MODULE_DEPENDENCIES})
        if (NOT StaticQt5${_module_dep}_FOUND)
            find_package(StaticQt5${_module_dep}
                5.7.1 ${_Qt5QuickTest_FIND_VERSION_EXACT}
                ${_Qt5QuickTest_DEPENDENCIES_FIND_QUIET}
                ${_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT StaticQt5${_module_dep}_FOUND)
            set(StaticQt5QuickTest_FOUND False)
            return()
        endif()

        list(APPEND StaticQt5QuickTest_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND StaticQt5QuickTest_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND StaticQt5QuickTest_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND StaticQt5QuickTest_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND StaticQt5QuickTest_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES StaticQt5QuickTest_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES StaticQt5QuickTest_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES StaticQt5QuickTest_DEFINITIONS)
    list(REMOVE_DUPLICATES StaticQt5QuickTest_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES StaticQt5QuickTest_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5QuickTest_LIB_DEPENDENCIES "StaticQt5::Test;StaticQt5::Widgets;StaticQt5::Core")


    add_library(StaticQt5::QuickTest STATIC IMPORTED)
    set_property(TARGET StaticQt5::QuickTest PROPERTY IMPORTED_LINK_INTERFACE_LANGUAGES CXX)

    macro(_process_prl_file PRL_FILE_LOCATION CONFIGURATION)
        if (EXISTS "${PRL_FILE_LOCATION}")
            file(STRINGS "${PRL_FILE_LOCATION}" prl_strings REGEX "QMAKE_PRL_LIBS_FOR_CMAKE")
            string(REGEX REPLACE "QMAKE_PRL_LIBS_FOR_CMAKE *= *([^\n]*)" "\\1" static_depends ${prl_strings})
            string(REGEX REPLACE "\\$\\$\\[QT_INSTALL_LIBS\\]" "${_qt5QuickTest_install_prefix}/lib" static_depends "${static_depends}")
            if (_Qt5QuickTest_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES)
                set(_list_sep ";")
            endif()
            set(_Qt5QuickTest_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES "${_Qt5QuickTest_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES}${_list_sep}${static_depends}")
        endif()
    endmacro()

    macro(_process_plugin_prl_file PRL_FILE_LOCATION CONFIGURATION LIB_DIRECTORY LIB_LOCATION)
        # First add the (static) plugin itself ...
        if (_Qt5QuickTest_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES)
            set(_list_sep ";")
        endif()
        set(_Qt5QuickTest_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES "${_Qt5QuickTest_STATIC_${CONFIGURATION}_LIB_DEPENDENCIES}${_list_sep}${_qt5QuickTest_install_prefix}/${LIB_DIRECTORY}/${LIB_LOCATION}")
        # .. then its dependencies.
        _process_prl_file(${PRL_FILE_LOCATION} ${CONFIGURATION})
    endmacro()

    _process_prl_file("${_qt5QuickTest_install_prefix}/lib/Qt5QuickTestd.static.prl" DEBUG)
    _process_prl_file("${_qt5QuickTest_install_prefix}/lib/Qt5QuickTest.static.prl" RELEASE)




    set_property(TARGET StaticQt5::QuickTest PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5QuickTest_OWN_INCLUDE_DIRS})
    set(interface_compile_definitions QT_QMLTEST_LIB)
    set_property(TARGET StaticQt5::QuickTest PROPERTY
        INTERFACE_COMPILE_DEFINITIONS QT_STATIC;QT_DESIGNER_STATIC QT_QMLTEST_LIB)
    file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/StaticQt5QuickTest_*.cmake")

    unset(pluginTargets)
    if(pluginTargetsMaybe)
        foreach(pluginTarget ${pluginTargetsMaybe})
            file(STRINGS ${pluginTarget} matched REGEX StaticQt5QuickTest_PLUGINS)
            if(matched)
                list(APPEND pluginTargets ${pluginTarget})
            endif()
        endforeach()
    endif()

    macro(_populate_QuickTest_plugin_properties_static TARGET_NAME PLUGIN_TARGET_NAME PLUGIN_NAME CONFIG PLUGIN_LOCATION)
        set_property(TARGET ${PLUGIN_TARGET_NAME} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${CONFIG})

        set(imported_location "${_qt5QuickTest_install_prefix}/lib/qt/plugins/${PLUGIN_LOCATION}")
        _qt5_QuickTest_check_file_exists_static(${imported_location})
        set_target_properties(${PLUGIN_TARGET_NAME} PROPERTIES
            "IMPORTED_LOCATION_${CONFIG}" ${imported_location}
        )
            set_property(TARGET ${TARGET_NAME} APPEND PROPERTY STATIC_PLUGINS ${PLUGIN_NAME})
            get_filename_component(_PLUGIN_DIR ${PLUGIN_LOCATION} PATH)
            get_filename_component(_PLUGIN_DIR_NAME ${_PLUGIN_DIR} NAME)
            get_filename_component(_PLUGIN_NAME ${PLUGIN_LOCATION} NAME)
            string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5QuickTest_install_prefix}/lib/qt/plugins/${_PLUGIN_DIR_NAME}/\\1.static.prl" PLUGIN_PRL_FILE_LOCATION ${_PLUGIN_NAME})
            _process_plugin_prl_file(${PLUGIN_PRL_FILE_LOCATION} ${CONFIG} "lib/qt/plugins" ${PLUGIN_LOCATION})

    endmacro()

    if(pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()

    _populate_QuickTest_target_properties_static(StaticQt5::QuickTest RELEASE "libQt5QuickTest.a" "" )


    if (EXISTS "${_qt5QuickTest_install_prefix}/lib/libQt5QuickTestd.a" )
        _populate_QuickTest_target_properties_static(StaticQt5::QuickTest DEBUG "libQt5QuickTestd.a" "" )
    endif()



_qt5_QuickTest_check_file_exists_static("${CMAKE_CURRENT_LIST_DIR}/StaticQt5QuickTestConfigVersion.cmake")

endif()
